part of 'additional_items_offline_bloc.dart';

class AdditionalItemsOfflineState extends Equatable {
  const AdditionalItemsOfflineState();

  @override
  List<Object> get props => [];
}

class AdditionalItemsOfflineInitial extends AdditionalItemsOfflineState {
  @override
  List<Object> get props => [];
}

class AdditionalItemsLoaded extends AdditionalItemsOfflineState {
  final List<AdditionalItems> addItem;

  const AdditionalItemsLoaded({required this.addItem});
  @override
  List<Object> get props => [addItem];
}

class LoadSpecificAdditionalItems extends AdditionalItemsOfflineState {
  final AdditionalItems addItem;

  const LoadSpecificAdditionalItems({required this.addItem});
  @override
  List<Object> get props => [addItem];
}

class ShowAddItemsScreen extends AdditionalItemsOfflineState {}

class AdditionalItemsErrorState extends AdditionalItemsOfflineState {
  const AdditionalItemsErrorState(this.error);
  final String error;

  @override
  List<Object> get props => [error];
}

class AdditionalItemsDeletedState extends AdditionalItemsOfflineState {
  final bool success;
  const AdditionalItemsDeletedState({required this.success});
  @override
  List<Object> get props => [success];
}
